        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==1 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==1 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==8 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==8 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==18 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==18 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==24 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==24 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==44 && cc==4){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==44 && cc==5){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==45 && cc==4){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==45 && cc==5){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
}
