        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 16 <strong>control</strong><br>0,2,4,10,13,14,17,19,25,26,30,32,33,34,40,43';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 14 <br>5,6,15,16,18,23,36,37,38,39,41,45,46,47';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 10 <br>1,3,11,12,24,27,29,31,35,42';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>22</strong> miembros: 10 <br>7,8,9,20,21,22,28,44,48,49';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260525 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>50</strong> miembros: 1 <br>50';}
}
